======
heat1d
======


.. image:: https://img.shields.io/pypi/v/heat1d.svg
        :target: https://pypi.python.org/pypi/heat1d

.. image:: https://img.shields.io/travis/phayne/heat1d.svg
        :target: https://travis-ci.org/phayne/heat1d

.. image:: https://readthedocs.org/projects/heat1d/badge/?version=latest
        :target: https://heat1d.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Thermal model for planetary science applications (Python version)


* Free software: MIT license
* Documentation: https://heat1d.readthedocs.io.

See the notebook_ for an example.

.. _notebook: https://nbviewer.jupyter.org/github/phayne/heat1d/blob/master/python/notebooks/heat1d_example.ipynb


Features
--------

* Modeling 1D heat transfer in planetary surfaces
* Provides library of required planetary surface parameters
* Plotting helpers (see notebook_)

Installation
------------

.. code-block:: bash

   pip install heat1d


Credits
---------

Author: P. Hayne

Package maintainer: K.-Michael Aye

This package was created with Cookiecutter_ and the forked `michaelaye/cookiecutter-pypackage-conda`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`michaelaye/cookiecutter-pypackage-conda`: https://github.com/michaelaye/cookiecutter-pypackage-conda
